@@ -29,8 +29,6 @@ struct _GgvControlPrivate {
 	float zoom_level;
 	gboolean has_zoomable_frame;
 
-	gboolean pane_auto_jump;
-
 	GtkWidget *root;
 
 	GtkObject *zoom_adj;
@@ -60,16 +58,6 @@ static struct {
 
 static BonoboControlClass *ggv_control_parent_class;
 
-static void
-ggv_control_prefs_changed(GConfClient *client, guint cnxn_id,
-						  GConfEntry *entry, gpointer user_data)
-{
-	GgvControl *control = GGV_CONTROL(user_data);
-
-	if(!strcmp(entry->key, "/apps/ggv/control/autojump"))
-	   control->priv->pane_auto_jump = gconf_value_get_bool(entry->value);
-}
-
 static void
 ggv_control_destroy (BonoboObject *object)
 {
@@ -329,29 +317,21 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		case GTK_GS_ORIENTATION_PORTRAIT:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_DOWN, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-				if(control->priv->pane_auto_jump)
-					gtk_gs_scroll_to_edge(gs, GTK_POS_TOP,  GTK_POS_TOP);
 			}
 			break;
 		case GTK_GS_ORIENTATION_LANDSCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_LEFT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-				if(control->priv->pane_auto_jump)
-					gtk_gs_scroll_to_edge(gs, GTK_POS_TOP,  GTK_POS_TOP);
 			}
 			break;
 		case GTK_GS_ORIENTATION_SEASCAPE:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_RIGHT, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-				if(control->priv->pane_auto_jump)
-					gtk_gs_scroll_to_edge(gs, GTK_POS_TOP,  GTK_POS_TOP);
 			}
 			break;
 		case GTK_GS_ORIENTATION_UPSIDEDOWN:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_UP, TRUE)) {
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-				if(control->priv->pane_auto_jump)
-					gtk_gs_scroll_to_edge(gs, GTK_POS_TOP,  GTK_POS_TOP);
 			}
 			break;
 		default:
@@ -399,13 +379,9 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		break;
 	case GDK_Page_Up:
 		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
-		if(control->priv->pane_auto_jump)
-			gtk_gs_scroll_to_edge(gs, GTK_POS_TOP, GTK_POS_TOP);
 		break;
 	case GDK_Page_Down:
 		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-		if(control->priv->pane_auto_jump)
-			gtk_gs_scroll_to_edge(gs, GTK_POS_TOP, GTK_POS_TOP);
 		break;
 	case GDK_plus:
 		g_signal_emit_by_name(G_OBJECT (control->priv->zoomable),
@@ -856,15 +832,6 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 	control->priv->uic =
 		bonobo_control_get_ui_component (BONOBO_CONTROL (control));
 
-	control->priv->pane_auto_jump = gconf_client_get_bool(gtk_gs_defaults_gconf_client(),
-														  "/apps/ggv/control/autojump",
-														  NULL);
-	control->priv->gconf_notify_id =
-		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
-								"/apps/ggv/control",
-								(GConfClientNotifyFunc)ggv_control_prefs_changed,
-								control, NULL, NULL);
-
 	return control;
 }
 
