@@ -24,6 +24,7 @@
 #include <gsdefaults.h>
 #include <ggvutils.h>
 #include <ggv-msg-window.h>
+#include <ggv-file-sel.h>
 #include <ggv-prefs.h>
 #include <ggv-prefs-ui.h>
 #include <ggv-sidebar.h>
@@ -42,7 +43,7 @@ struct _GgvPostScriptViewPrivate {
 	gint magstep;
 	gboolean pan;
 	gdouble prev_x, prev_y;
-	gchar *tmp_name;
+	gchar *tmp_name, *uri;
 	guint gconf_notify_id;
 
 	GgvMsgWindow *msg_win;
@@ -54,6 +55,8 @@ struct _GgvPostScriptViewPrivate {
 	BonoboUIComponent     *uic, *popup_uic;
 
 	gboolean               zoom_fit;
+
+	gboolean pane_auto_jump;
 };
 
 struct _GgvPostScriptViewClassPrivate {
@@ -148,13 +151,15 @@ get_title(GgvPostScriptView *ps_view, BonoboArg *arg)
 static void
 set_file_items_sensitivity(GgvPostScriptView *ps_view, gboolean sens)
 {
-	gchar *prop_val = sens?"1":"0";
+	gchar *prop_val;
 	Bonobo_UIContainer container;
 
 	container = bonobo_ui_component_get_container (ps_view->priv->uic);
 	if (container == CORBA_OBJECT_NIL)
 		return;
 
+	prop_val = (sens && !GTK_GS_IS_PDF(ps_view->priv->gs))?"1":"0";
+
 	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FileSaveMarked",
 								 "sensitive", prop_val, NULL);
@@ -285,6 +290,10 @@ ggv_postscript_view_goto_page(GgvPostScriptView *ps_view, gint page)
 	gtk_gs_goto_page(GTK_GS(ps_view->priv->gs), page);
 	if(gtk_gs_get_current_page(GTK_GS(ps_view->priv->gs)) != old_page) {
 		notify_page_change(ps_view);
+		if(ps_view->priv->pane_auto_jump) {
+			gtk_gs_scroll_to_edge(GTK_GS(ps_view->priv->gs),
+								  GTK_POS_TOP,  GTK_POS_TOP);
+		}
 	}
 }
 
@@ -506,6 +515,7 @@ load_ps_from_file (BonoboPersistFile *pf, const CORBA_char *filename,
 	GnomeVFSFileSize bytes_read = 0;
 	guchar *buffer;
 	GgvPostScriptView *ps_view;
+	gchar *local_file = NULL;
 	FILE *tmpfile;
 
 	g_return_val_if_fail (data != NULL, -1);
@@ -513,38 +523,49 @@ load_ps_from_file (BonoboPersistFile *pf, const CORBA_char *filename,
 
 	ps_view = GGV_POSTSCRIPT_VIEW(data);
 
-	uri = gnome_vfs_uri_new(filename);
-	/* open uri */
-	result = gnome_vfs_open_uri(&handle, uri, GNOME_VFS_OPEN_READ);
-	gnome_vfs_uri_unref(uri);
-	if(result != GNOME_VFS_OK) {
-		return -1;
-	}
-
 	ps_view_clean_tmp_file(ps_view);
-	tmpfile = ps_view_get_tmp_file(ps_view);
 
-	buffer = g_new0(guchar, 4096);
-	do {
-		result = gnome_vfs_read (handle, buffer,
-					 4096, &bytes_read);
-		if (result != GNOME_VFS_OK)
-			break;
+	uri = gnome_vfs_uri_new(filename);
+	if(gnome_vfs_uri_is_local(uri)) {
+		local_file = g_strdup(gnome_vfs_uri_get_path(uri));
+	}
+	else {
+		/* open uri */
+		result = gnome_vfs_open_uri(&handle, uri, GNOME_VFS_OPEN_READ);
+		gnome_vfs_uri_unref(uri);
+		if(result != GNOME_VFS_OK) {
+			return -1;
+		}
 
-		if (bytes_read > 0)
-			if(fwrite(buffer, 1, bytes_read, tmpfile) != bytes_read) {
-				result = GNOME_VFS_ERROR_GENERIC;
+		tmpfile = ps_view_get_tmp_file(ps_view);
+
+		buffer = g_new0(guchar, 4096);
+		do {
+			result = gnome_vfs_read (handle, buffer,
+									 4096, &bytes_read);
+			if (result != GNOME_VFS_OK)
 				break;
-			}
-	} while(TRUE);
+			
+			if (bytes_read > 0)
+				if(fwrite(buffer, 1, bytes_read, tmpfile) != bytes_read) {
+					result = GNOME_VFS_ERROR_GENERIC;
+					break;
+				}
+		} while(TRUE);
 
-	gnome_vfs_close(handle);
-	fclose(tmpfile);
+		gnome_vfs_close(handle);
+		fclose(tmpfile);
 
-	if(result != GNOME_VFS_ERROR_EOF)
-		return -1;
-	
-	load_ps(ps_view, ps_view->priv->tmp_name);
+		if(result != GNOME_VFS_ERROR_EOF)
+			return -1;
+	}
+	if(ps_view->priv->tmp_name) {
+		load_ps(ps_view, ps_view->priv->tmp_name);
+	}
+	else if(local_file) {
+		load_ps(ps_view, local_file);
+		g_free(local_file);
+	}
 
 	return 0;
 }
@@ -795,8 +816,8 @@ verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
 	g_free(active_rows);
 
 	if(doc != NULL) {
-		fname = bonobo_file_selector_open(GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
-										  TRUE, _("Select a file to save pages as"), NULL, NULL);
+		fname = ggv_file_sel_request_uri(_("Select a file to save pages as"),
+										 NULL);
 		if(fname) {
 			if(ggv_file_readable(fname)) {
 				GtkWidget *dlg;
@@ -1650,6 +1671,8 @@ ggv_postscript_view_finalize(GObject *object)
 
 	ps_view = GGV_POSTSCRIPT_VIEW(object);
 
+	ps_view_clean_tmp_file(ps_view);
+
 	g_free(ps_view->priv);
 
 	G_OBJECT_CLASS(ggv_postscript_view_parent_class)->finalize(object);
@@ -1802,6 +1825,8 @@ property_control_get_cb(BonoboPropertyControl *property_control,
 static void
 document_changed_cb(GtkGS *gs, gpointer data)
 {
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+
 	gtk_gs_reload(gs);
 	notify_page_count_change(GGV_POSTSCRIPT_VIEW(data));
 	notify_page_change(GGV_POSTSCRIPT_VIEW(data));
@@ -1851,44 +1876,69 @@ ggv_postscript_view_prefs_changed(GConfClient *client, guint cnxn_id,
 	GtkGS *gs = GTK_GS(ps_view->priv->gs);
 
 	if(!strcmp(entry->key, "/apps/ggv/gtkgs/respect_eof")) 
-		gtk_gs_set_respect_eof(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/respect_eof", NULL));
+		gtk_gs_set_respect_eof(gs, gconf_value_get_bool(entry->value));
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_orientation")) {
-		gtk_gs_set_override_orientation(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_orientation",
-																  NULL));
+		gtk_gs_set_override_orientation(gs, 
+										gconf_value_get_bool(entry->value));
 		sync_orientation_items(ps_view);
 	}
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/orientation")) {
-		gtk_gs_set_default_orientation(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/orientation",
-																NULL));
+		gtk_gs_set_default_orientation(gs, gconf_value_get_int(entry->value));
 		sync_orientation_items(ps_view);
 	}
 #if 0
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/zoom")) {
-		gtk_gs_set_zoom(gs, gconf_client_get_float(client, "/apps/ggv/gtkgs/zoom",
-												   NULL));
+		gtk_gs_set_zoom(gs, gconf_value_get_float(entry->value));
 	}
 #endif
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/size")) {
-		gtk_gs_set_default_size(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/size",
-														 NULL));
+		gtk_gs_set_default_size(gs, gconf_value_get_int(entry->value));
 		sync_size_items(ps_view);
 	}
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/antialiasing"))
-		gtk_gs_set_antialiasing(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/antialiasing",
-														  NULL));
+		gtk_gs_set_antialiasing(gs, gconf_value_get_bool(entry->value));
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_size")) {
-		gtk_gs_set_override_size(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_size",
-														   NULL));
+		gtk_gs_set_override_size(gs, gconf_value_get_bool(entry->value));
 		sync_size_items(ps_view);
 	}
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
-		gtk_gs_set_watch_file(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/watch_doc",
-														NULL));
+		gtk_gs_set_watch_file(gs, gconf_value_get_bool(entry->value));
 	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/show_scroll_rect"))
-		gtk_gs_set_show_scroll_rect(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/show_scroll_rect",
-															  NULL));
+		gtk_gs_set_show_scroll_rect(gs, gconf_value_get_bool(entry->value));
+	else if(!strcmp(entry->key, "/apps/ggv/control/autojump"))
+	   ps_view->priv->pane_auto_jump = gconf_value_get_bool(entry->value);
 }
 
+static gboolean
+sidebar_key_press_event(GtkWidget *widget, GdkEventKey *event,
+						gpointer data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
+	GtkGS *gs;
+
+	if(ps_view->priv->gs)
+		gs = GTK_GS(ps_view->priv->gs);
+	else
+		return TRUE;
+
+	switch(event->keyval) {
+	case GDK_Left:
+		gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_LEFT, FALSE);
+		break;
+	case GDK_Right:
+		gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_RIGHT, FALSE);
+		break;
+	case GDK_Up:
+		gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_UP, FALSE);
+		break;
+	case GDK_Down:
+		gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_DOWN, FALSE);
+		break;
+	default:
+		return FALSE;
+	}
+	return TRUE;
+}
 
 GgvPostScriptView *
 ggv_postscript_view_construct(GgvPostScriptView *ps_view,
@@ -1907,7 +1957,7 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 
 	ps_view->priv->gconf_notify_id =
 		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
-								"/apps/ggv/gtkgs",
+								"/apps/ggv",
 								(GConfClientNotifyFunc)ggv_postscript_view_prefs_changed,
 								ps_view, NULL, NULL);
 															 
@@ -2013,7 +2063,12 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 	ps_view->priv->uic = bonobo_ui_component_new("GgvPostScriptView");
 
 	ps_view->priv->sidebar = ggv_sidebar_new(ps_view);
+	g_signal_connect(G_OBJECT(ggv_sidebar_get_checklist(ps_view->priv->sidebar)),
+					 "key_press_event", G_CALLBACK(sidebar_key_press_event), ps_view);
 
+	ps_view->priv->pane_auto_jump = gconf_client_get_bool(gtk_gs_defaults_gconf_client(),
+														  "/apps/ggv/control/autojump",
+														  NULL);
 	return ps_view;
 }
 
