@@ -372,3 +372,9 @@ ggv_sidebar_update_coordinates(GgvSidebar *sidebar, gfloat xcoord, gfloat ycoord
 		g_free(clabel);
 	}
 }
+
+GtkWidget *
+ggv_sidebar_get_checklist(GgvSidebar *sidebar)
+{
+	return sidebar->priv->checklist;
+}
