@@ -19,9 +19,7 @@ static GConfClient *gconf_client = NULL;
 gchar    *ggv_print_cmd = NULL;
 gboolean  ggv_save_geometry = FALSE;
 gint      ggv_default_width = DEFAULT_WINDOW_WIDTH;
-gint      file_sel_width = DEFAULT_FILE_SEL_WIDTH;
 gint      ggv_default_height = DEFAULT_WINDOW_HEIGHT;
-gint      file_sel_height = DEFAULT_FILE_SEL_HEIGHT;
 
 gboolean ggv_panel = TRUE, ggv_menubar = TRUE, ggv_toolbar = TRUE;
 gboolean ggv_statusbar = TRUE, ggv_autojump = TRUE;
@@ -78,12 +76,6 @@ ggv_prefs_load()
         if((ggv_default_height = gconf_client_get_int
             (gconf_client, "/apps/ggv/layout/windowheight", NULL)) == 0)
                 ggv_default_height = DEFAULT_WINDOW_HEIGHT;
-        if((file_sel_width = gconf_client_get_int
-            (gconf_client, "/apps/ggv/layout/fileselwidth", NULL)) == 0)
-                file_sel_width = DEFAULT_FILE_SEL_WIDTH;
-        if((file_sel_height = gconf_client_get_int
-            (gconf_client, "/apps/ggv/layout/fileselheight", NULL)) == 0)
-                file_sel_height = DEFAULT_FILE_SEL_WIDTH;
 }
 
 void
@@ -116,10 +108,6 @@ ggv_prefs_save()
                                      ggv_default_width, NULL);
                 gconf_client_set_int(gconf_client, "/apps/ggv/layout/windowheight",
                                      ggv_default_height, NULL);
-                gconf_client_set_int(gconf_client, "/apps/ggv/layout/fileselwidth",
-                                     file_sel_width, NULL);
-                gconf_client_set_int(gconf_client, "/apps/ggv/layout/fileselheight",
-                                     file_sel_height, NULL);
         }
 }
 
@@ -187,16 +175,6 @@ ggv_prefs_changed(GConfClient* client, guint cnxn_id,
                     (gconf_client, "/apps/ggv/layout/windowheight", NULL)) == 0)
                         ggv_default_height = DEFAULT_WINDOW_HEIGHT;
         }
-        else if(!strcmp(entry->key, "/apps/ggv/layout/fileselwidth")) {
-                if((file_sel_width = gconf_client_get_int
-                    (gconf_client, "/apps/ggv/layout/fileselwidth", NULL)) == 0)
-                        file_sel_width = DEFAULT_FILE_SEL_WIDTH;
-        }
-        else if(!strcmp(entry->key, "/apps/ggv/layout/fileselheight")) {
-                if((file_sel_height = gconf_client_get_int
-                    (gconf_client, "/apps/ggv/layout/fileselheight", NULL)) == 0)
-                        file_sel_height = DEFAULT_FILE_SEL_WIDTH;
-        }
 }
 
 GConfClient *
