@@ -22,6 +22,7 @@
 #include "gtkchecklist.h"
 #include "ggv-prefs.h"
 #include "ggv-window.h"
+#include "ggv-file-sel.h"
 #include "ggvutils.h"
 
 #define GGV_POSTSCRIPT_VIEWER_CONTROL_IID "OAFIID:GNOME_GGV_Control"
@@ -229,9 +230,8 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
         GgvWindow *win = GGV_WINDOW(data);
         gchar *fname, *escaped_fname;
 
-        fname = bonobo_file_selector_open(GTK_WINDOW(win), TRUE,
-                                          _("Select a PostScript document"),
-                                          NULL, NULL);
+        fname = ggv_file_sel_request_uri(_("Select a PostScript document"),
+                                         NULL);
         if(fname) {
                 if(!ggv_window_load(win, fname)) {
                         GtkWidget *dlg;
@@ -820,7 +820,7 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
 {
         CORBA_Environment ev;
         Bonobo_PersistFile pf;
-        gchar *title;
+        gchar *title, *unescaped;
 
         g_return_val_if_fail(win != NULL, FALSE);
         g_return_val_if_fail(GGV_IS_WINDOW(win), FALSE);
@@ -841,7 +841,9 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
                 g_free(win->filename);
         win->filename = g_strdup(filename);
 
-        title = g_strconcat(_("GGV: "), win->filename, NULL);
+        unescaped = gnome_vfs_unescape_string_for_display(win->filename);
+        title = g_strconcat(_("GGV: "), unescaped, NULL);
+        g_free(unescaped);
         gtk_window_set_title(GTK_WINDOW(win), title);
         g_free(title);
 
