@@ -482,6 +482,7 @@ gtk_gs_cleanup (GtkGS *gs)
 static void
 gtk_gs_interpreter_message(GtkGS *gs, gchar *msg, gpointer user_data)
 {
+        gdk_pointer_ungrab(GDK_CURRENT_TIME);
         if(strstr(msg, "Error:")) {
                 gs->gs_status = _("File is not a valid PostScript document.");
                 gtk_gs_cleanup(gs);
@@ -551,6 +552,7 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 		x = (gs->widget.allocation.width - gs->width)/2;
 		gs->hadj->value = 0.0;
 		gs->hadj->page_size = 1.0;
+                gs->hadj->step_increment = 1.0;
 	}
         else {
 		if (x > 0)
@@ -559,12 +561,14 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			x = gs->widget.allocation.width - gs->width;
 		gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
                 gs->hadj->page_increment = gs->hadj->page_size*0.9;
+                gs->hadj->step_increment = 1.0/gs->width;
 		gs->hadj->value = -((gfloat)x)/gs->width;
 	}
 	if (gs->widget.allocation.height >= gs->height) {
 		y = (gs->widget.allocation.height - gs->height)/2;
 		gs->vadj->value = 0.0;
 		gs->vadj->page_size = 1.0;
+                gs->vadj->step_increment = 1.0;
 	}
         else {
 		if (y > 0)
@@ -573,13 +577,11 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			y = gs->widget.allocation.height - gs->height;
 		gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
                 gs->vadj->page_increment = gs->vadj->page_size*0.9;
+                gs->vadj->step_increment = 1.0/gs->height;
 		gs->vadj->value = -((gfloat)y)/gs->height;
 	}
 
-	gdk_window_move(gs->pstarget, x, y);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
+        gdk_window_move(gs->pstarget, x, y);
 
 	gtk_adjustment_changed (gs->hadj);
 	gtk_adjustment_changed (gs->vadj);
@@ -739,9 +741,6 @@ gtk_gs_value_adjustment_changed (GtkAdjustment *adjustment, gpointer data)
                 newy = -gs->vadj->value*gs->height;
 
         gdk_window_move(gs->pstarget, newx, newy);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
 }
 
 void
@@ -1326,12 +1325,14 @@ check_filecompressed (GtkGS *gs)
 	filename = ggv_quote_filename (gs->gs_filename);
 	filename_unc = g_strconcat (g_get_tmp_dir(), "/ggvXXXXXX", NULL);
         if((fd = mkstemp(filename_unc)) < 0) {
+                g_free(filename_unc);
                 g_free(filename);
                 return NULL;
         }
         close(fd);
 	filename_err = g_strconcat (g_get_tmp_dir(), "/ggvXXXXXX", NULL);
         if((fd = mkstemp(filename_err)) < 0) {
+                g_free(filename_err);
                 g_free(filename_unc);
                 g_free(filename);
                 return NULL;
@@ -1442,6 +1443,9 @@ check_pdf (GtkGS *gs)
 	return filename;
 }
 
+#ifdef BROKEN_XINERAMA_PATCH_THAT_SHOULD_NOT_BE_USED
+/* never mind this patch: a properly working X server should take care of
+   calculating the proper values. */
 static float
 compute_xdpi(void)
 {
@@ -1481,6 +1485,19 @@ compute_ydpi(void)
         }
 #endif /* HAVE_XINERAMA */
 }
+#else
+static float
+compute_xdpi(void)
+{
+        return 25.4 * gdk_screen_width()/gdk_screen_width_mm();
+}
+
+static float
+compute_ydpi(void)
+{
+        return 25.4 * gdk_screen_height()/gdk_screen_height_mm();
+}
+#endif /* BROKEN_XINERAMA_PATCH_THAT_SHOULD_NOT_BE_USED */
 
 /* Compute new size of window, sets xdpi and ydpi if necessary.
  * returns True if new window size is different */
@@ -1642,11 +1659,8 @@ gtk_gs_center_page(GtkGS *gs)
 	g_return_if_fail (GTK_IS_GS(gs));
 
         gdk_window_move(gs->pstarget,
-                        (gs->widget.allocation.width - gs->width)/2,
-                        (gs->widget.allocation.height - gs->height)/2);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
+                         (gs->widget.allocation.width - gs->width)/2,
+                         (gs->widget.allocation.height - gs->height)/2);
         gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
         gs->hadj->page_size = MIN(gs->hadj->page_size, 1.0);
         gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
@@ -2130,6 +2144,7 @@ gtk_gs_set_zoom (GtkGS *gs, gfloat zoom) {
                 gs->changed = TRUE;
         }
 	gtk_widget_queue_resize (&(gs->widget));
+
 }
 
 gfloat
@@ -2426,11 +2441,11 @@ gtk_gs_scroll_to_edge(GtkGS *gs, GtkPositionType vertical, GtkPositionType horiz
         g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
         switch (vertical) {
-        case GTK_POS_BOTTOM:
+        case GTK_POS_TOP:
                 gs->vadj->value = gs->vadj->lower;
                 gtk_adjustment_value_changed(gs->vadj);
                 break;
-        case GTK_POS_TOP:
+        case GTK_POS_BOTTOM:
                 gs->vadj->value = gs->vadj->upper - gs->vadj->page_size;
                 gtk_adjustment_value_changed(gs->vadj);
                 break;
@@ -2439,12 +2454,12 @@ gtk_gs_scroll_to_edge(GtkGS *gs, GtkPositionType vertical, GtkPositionType horiz
         }
 
 
-        switch (vertical) {
-        case GTK_POS_BOTTOM:
+        switch (horizontal) {
+        case GTK_POS_TOP:
                 gs->hadj->value = gs->hadj->lower;
                 gtk_adjustment_value_changed(gs->hadj);
                 break;
-        case GTK_POS_TOP:
+        case GTK_POS_BOTTOM:
                 gs->hadj->value = gs->hadj->upper - gs->hadj->page_size;
                 gtk_adjustment_value_changed(gs->hadj);
                 break;
@@ -2649,6 +2664,7 @@ gtk_gs_set_adjustments (GtkGS         *gs,
                 hadj->upper = 1.0;
                 hadj->value = 0.0;
                 hadj->page_size = 1.0;
+                hadj->page_increment = 1.0;
                 gs->hadj = hadj;
                 gtk_object_ref (GTK_OBJECT (gs->hadj));
                 gtk_object_sink (GTK_OBJECT (gs->hadj));
@@ -2662,6 +2678,7 @@ gtk_gs_set_adjustments (GtkGS         *gs,
                 vadj->upper = 1.0;
                 vadj->value = 0.0;
                 vadj->page_size = 1.0;
+                vadj->page_increment = 1.0;
                 gs->vadj = vadj;
                 gtk_object_ref (GTK_OBJECT (gs->vadj));
                 gtk_object_sink (GTK_OBJECT (gs->vadj));
